@@ -84,7 +84,10 @@ class Session:
             )
         return self._session
 
-    async def get(self, endpoint: str,) -> Union[Dict[str, Any], List[Any]]:
+    async def get(
+        self,
+        endpoint: str,
+    ) -> Union[Dict[str, Any], List[Any]]:
         return await self.request('GET', endpoint, {})
 
     async def post(
@@ -93,12 +96,19 @@ class Session:
         return await self.request('POST', endpoint, data)
 
     async def request(
-        self, method: str, endpoint: str, data: Dict[str, Any], **kwargs: Any,
+        self,
+        method: str,
+        endpoint: str,
+        data: Dict[str, Any],
+        **kwargs: Any,
     ) -> Union[Dict[str, Any], List[Any]]:
         session = await self.session()
         url = self.base_url + endpoint
         async with session.request(
-            method, url, json=data, **kwargs,
+            method,
+            url,
+            json=data,
+            **kwargs,
         ) as response:
             await self._check_response(response)
             resultado = await response.json()
@@ -107,7 +117,11 @@ class Session:
         return resultado
 
     async def soap_request(
-        self, method: str, endpoint: str, data: str, **kwargs: Any,
+        self,
+        method: str,
+        endpoint: str,
+        data: str,
+        **kwargs: Any,
     ):
         session = await self.session()
         url = self.soap_url + endpoint
